---
search:
  exclude: true
---
# リリースプロセス / 変更履歴

このプロジェクトは、`0.Y.Z` という形式を用いる、やや調整したセマンティックバージョニングに従います。先頭の `0` は、この SDK が依然として急速に進化中であることを示します。各コンポーネントの増分ルールは以下のとおりです。

## マイナー（`Y`）バージョン

ベータではないパブリックインターフェースに対する **後方互換性のない変更** に対して、マイナーバージョン `Y` を増やします。たとえば、`0.0.x` から `0.1.x` になる際には、後方互換性のない変更が含まれる可能性があります。

後方互換性のない変更を避けたい場合は、プロジェクトで `0.0.x` のバージョンに固定することをおすすめします。

## パッチ（`Z`）バージョン

後方互換性を壊さない変更に対して、`Z` を増やします。

- バグ修正
- 新機能
- プライベートインターフェースの変更
- ベータ機能の更新

## 互換性を壊す変更の変更履歴

### 0.5.0

このバージョンでは目に見える互換性破壊的な変更は導入していませんが、新機能と内部実装の重要な更新をいくつか含みます。

- `RealtimeRunner` が [SIP プロトコル接続](https://platform.openai.com/docs/guides/realtime-sip) を扱えるようになりました
- Python 3.14 との互換性のため、`Runner#run_sync` の内部ロジックを大幅に見直しました

### 0.4.0

このバージョンでは、[openai](https://pypi.org/project/openai/) パッケージの v1.x はサポート対象外になりました。この SDK と併せて openai v2.x をご利用ください。

### 0.3.0

このバージョンでは、Realtime API のサポートが gpt-realtime モデルとその API インターフェース（GA 版）に移行します。

### 0.2.0

このバージョンでは、これまで `Agent` を引数に受け取っていた箇所の一部が、代わりに `AgentBase` を引数に受け取るようになりました。たとえば、MCP サーバーの `list_tools()` 呼び出しなどです。これは型付けのみの変更であり、引き続き `Agent` オブジェクトを受け取ります。更新の際は、`Agent` を `AgentBase` に置き換えて型エラーを解消してください。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に `run_context` と `agent` の 2 つの新しいパラメーターが追加されました。`MCPServer` を継承するすべてのクラスに、これらのパラメーターを追加する必要があります。